aboutsummaryrefslogtreecommitdiff
path: root/src/drivers/intel/fsp1_0/fastboot_cache.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/drivers/intel/fsp1_0/fastboot_cache.c')
-rw-r--r--src/drivers/intel/fsp1_0/fastboot_cache.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/drivers/intel/fsp1_0/fastboot_cache.c b/src/drivers/intel/fsp1_0/fastboot_cache.c
index 68150f9379..b57f382b27 100644
--- a/src/drivers/intel/fsp1_0/fastboot_cache.c
+++ b/src/drivers/intel/fsp1_0/fastboot_cache.c
@@ -209,16 +209,16 @@ void update_mrc_cache(void *unused)
"Need to erase the MRC cache region of %d bytes at %p\n",
cache_size, cache_base);
- flash->erase(flash, to_flash_offset(cache_base), cache_size);
+ spi_flash_erase(flash, to_flash_offset(cache_base), cache_size);
/* we will start at the beginning again */
cache = cache_base;
}
/* 4. write mrc data with flash->write() */
printk(BIOS_DEBUG, "Write MRC cache update to flash at %p\n",
cache);
- flash->write(flash, to_flash_offset(cache),
- current->mrc_data_size + sizeof(*current), current);
+ spi_flash_write(flash, to_flash_offset(cache),
+ current->mrc_data_size + sizeof(*current), current);
}
#endif /* !defined(__PRE_RAM__) */
@@ -209,16 +209,16 @@ void update_mrc_cache(void *unused)
cache = cache_base;
}
- /* 4. write mrc data with flash->write() */
+ /* 4. write mrc data with spi_flash_write() */
printk(BIOS_DEBUG, "Write MRC cache update to flash at %p\n",
cache);